/**
 * Releases a new version of the deep npm package and syncronizes the version and dependencies between {@link NpmReleaseParam.deepJsonFilePath} and {@link NpmReleaseParam.packageJsonFilePath}
 *
 * @throws {@link Error} if the version in {@link NpmReleaseParam.packageJsonFilePath} is outdated
 *
 * @example
```typescript
await npmRelease({
  newVersion: '1.0.0',
  packageJsonFilePath: 'package.json',
  deepJsonFilePath: 'deep.json',
})
```
 *
 */
export declare function npmRelease(param: NpmReleaseParam): Promise<void>;
export interface NpmReleaseParam {
    /**
     * New version to release
     *
     * @remarks
     * You can also use 'patch', 'minor' or 'major' to increase the version as you do with `npm version`
     */
    newVersion: string;
    /**
     * Path to package.json
     */
    packageJsonFilePath: string;
    /**
     * Path to deep.json
     */
    deepJsonFilePath: string;
}
